# Blue Hue
### A Platform Game By Joachim Ford

This game involves collecting the 'coins' in each level and reaching the finish square.
Each world has many features including spikes, bounce blocks, darkness blocks, crumble blocks, keys, locks and more.

Use the arrow keys, WASD or ZQSD to control the player around each level.

[JoachimFord.uk](https://joachimford.uk)
